StringValidator extension

String extension functions for Text field validations

on

Methods

isNotNullOrEmpty() → bool

Available on String?, provided by the StringValidator extension

Return true if given string is not null or empty
isNullOrEmpty() → bool

Available on String?, provided by the StringValidator extension

Return true if given string is null or empty
isValidEmail() → bool

Available on String?, provided by the StringValidator extension

Return true if given string is valid email and not empty or null